@@ -18,24 +18,24 @@ function(content)
 setGeneric("fromJSON",
             function(content, handler = NULL, default.size = 100, depth = 150L,
                       allowComments = TRUE,  asText = isContent(content),
-                       data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, ...)
+                       data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE,  nullValue = NULL, ...)
                   standardGeneric("fromJSON"))
 
 setMethod("fromJSON", c("AsIs", handler = "NULL"),
 function(content,  handler = NULL, default.size = 100, depth = 150L,
 	 allowComments = TRUE,  asText = isContent(content),
-            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, ...)
+            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, nullValue = NULL, ...)
 {
-  .Call("R_fromJSON", content, as.logical(simplify))
+  .Call("R_fromJSON", content, as.logical(simplify), nullValue)  
 })
 
 setMethod("fromJSON", "AsIs",
 function(content, handler = NULL, default.size = 100,
          depth = 150L, allowComments = TRUE, asText = isContent(content),
-            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, ...)  
+            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, nullValue = NULL, ...)  
 {
    fromJSON(as.character(content), handler, default.size, depth, allowComments, asText = TRUE, data, maxChar,
-             simplify = simplify, ...)  
+             simplify = simplify, ..., nullValue = nullValue)  
 })
 
 
@@ -43,7 +43,7 @@ function(content, handler = NULL, default.size = 100,
 setMethod("fromJSON", c("character"),
 function(content, handler = NULL,
           default.size = 100, depth = 150L, allowComments = TRUE, asText = isContent(content),
-            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, ...)  
+            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, nullValue = NULL, ...)  
 {
   if(!asText) {
     content = I(suppressWarnings(paste(readLines(content), collapse = "\n")))
@@ -51,23 +51,23 @@ function(content, handler = NULL,
   } else
     content = I(content)
 
-  fromJSON(content, handler, default.size, depth, allowComments, asText = FALSE, data, maxChar, simplify = simplify, ...)
+  fromJSON(content, handler, default.size, depth, allowComments, asText = FALSE, data, maxChar, simplify = simplify, ..., nullValue = nullValue)
 })
 
   
 setMethod("fromJSON", c("AsIs", "JSONParserHandler"),
 function(content, handler = NULL,
           default.size = 100, depth = 150L, allowComments = TRUE, asText = isContent(content),
-            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, ...)  
+            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, nullValue = NULL, ...)  
 {
-  fromJSON(content, handler$update, depth = depth, allowComments = allowComments, maxChar = maxChar, simplify = simplify, ...)
+  fromJSON(content, handler$update, depth = depth, allowComments = allowComments, maxChar = maxChar, simplify = simplify, ..., nullValue = nullValue)
   handler$value()
 })
 
 setMethod("fromJSON", c("AsIs", "function"),
 function(content, handler = NULL,
           default.size = 100, depth = 150L, allowComments = TRUE, asText = isContent(content),
-            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, ...)  
+            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, nullValue = NULL, ...)  
 {
   oldFromJSON(content, handler, depth = depth, allowComments = allowComments, maxChar = maxChar, simplify = simplify, ...)
 })
@@ -75,7 +75,7 @@ function(content, handler = NULL,
 setMethod("fromJSON", c("AsIs", "NativeSymbolInfo"),
 function(content, handler = NULL,
           default.size = 100, depth = 150L, allowComments = TRUE, asText = isContent(content),
-            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, ...)  
+            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, nullValue = NULL, ...)  
 {
   oldFromJSON(content, handler$address, depth = depth, allowComments = allowComments, data = data, maxChar = maxChar, simplify = simplify, ...)
 })
@@ -83,7 +83,7 @@ function(content, handler = NULL,
 oldFromJSON = 
 function(content, handler = NULL,
           default.size = 100, depth = 150L, allowComments = TRUE, asText = isContent(content),
-            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, ...)  
+            data = NULL, maxChar = c(0L, nchar(content)), simplify = TRUE, nullValue = NULL, ...)  
 {
   if(inherits(handler, "NativeSymbol")) {
      data = list(handler, data)
@@ -110,11 +110,11 @@ function(content, handler = NULL,
 setMethod("fromJSON", "connection",
 function(content, handler = NULL, default.size = 100,
          depth = 150L, allowComments = TRUE, asText = isContent(content),
-            data = NULL, maxChar = c(0L, nchar(content)), maxNumLines = -1L, simplify = TRUE, ...)  
+            data = NULL, maxChar = c(0L, nchar(content)), maxNumLines = -1L, simplify = TRUE, nullValue = NULL, ...)  
 {
   txt = paste(readLines(content, maxNumLines), collapse = "")
   fromJSON(I(txt), handler, default.size, depth, allowComments, asText = TRUE, data = data, maxNumLines = maxNumLines,
-             simplify = simplify, ...)
+             simplify = simplify, ..., nullValue = nullValue)
 })
 
 
